/**
 * 这里写模块内部的消息处理函数，供原生回调H5
 */
define(function(require, exports, module){
	var	gconfig = require("gconfig");
	var	global = gconfig.global;
	var appUtils = require("appUtils");
	var	layerUtils = require("layerUtils");
	var oMyMsgFunction = {}; // 暴露给外部的对象
	var msgFunction = require("msgFunction"); // 加载 plugins 目录里面公用的 msgFunction
	
	/*将本文件里面的函数和 plugins 目录里面公用的 msgFunction 中的函数进行合并操作*/
	msgFunction.conbine(oMyMsgFunction);
	/*将本文件里面的函数和 plugins 目录里面公用的 msgFunction 中的函数进行合并操作，请务必将这句代码放在模块最前面*/
	
	/**
	 * 公用		
	 * 弹出通讯录，用于选择联系人的信息，选择完毕后回调H5
	 * 说明：通讯录插件的调用必须要写在页面UI的事件处理函数中，否则多模块开发原生无法获取到当前激活的模块从而导致无法回调H5
	 * @param funcNo 50223
	 * @param name String 名称 Y
	 * @param phone String 手机号码 Y
	 */
	oMyMsgFunction.function50223 = function(paramMap) 
	{
		var selPhoneCallback = window.selPhoneCallback; // 选择电话联系人的回调函数
		if(selPhoneCallback)
		{
			selPhoneCallback(paramMap);
		}
	}
	
	/**
	 * 公用		
	 * 日期控件回调H5
	 * 说明：日期控件的调用必须要写在页面UI的事件处理函数中，否则多模块开发原生无法获取到当前激活的模块从而导致无法回调H5
	 * @param funcNo 50251
	 * @param date String 日期 Y
	 * @param selector String H5的元素选择器 N
	 */
	oMyMsgFunction.function50251 = function(paramMap) 
	{
		paramMap = paramMap || {};
		var selDateCallback = window.selDateCallback; // 选择日期的回调函数
		if(selDateCallback)
		{
			selDateCallback(paramMap);
		}
	}
	
	/**
	 * 公用		
	 * 设置系统软件的主题风格
	 * @param funcNo 50104
	 * @param theme String 主题颜色(见数据字典) Y 0：红色，1：蓝色，2：黑色，3：黄色，9：绿色
	 */
	oMyMsgFunction.function50104 = function(paramMap) 
	{
		if(paramMap)
		{
			var $appCss = $("head>link[href*='" + gconfig.firstLoadCss[0] + "']");
			var skinMap = {0: "red", 1: "blue", 2: "black", 3: "yellow", 9: "green"};
			var href = gconfig.cssPath + "style_" + skinMap[paramMap.theme] + ".css";
			gconfig.firstLoadCss[0] = href; // 修改当前皮肤对应的 css
			$appCss.attr("href", href);
			var originalOverflow = $("body").css("overflow");
			$("body").css("overflow", "auto"); // 强制浏览器重绘
			$("body").css("overflow", originalOverflow);
		}
	}

	/**
	 * 公用		
	 * 原生的信息提示框回调H5
	 * @param funcNo 50111
	 * @param flag	String	业务标志	N
	 */
	oMyMsgFunction.function50111 = function(paramMap) 
	{
		if(paramMap)
		{
			layerUtils.iAlert(paramMap.flag);
		}
	}

	/**
	 * 公用		
	 * 通知H5分享后的状态
	 * @param funcNo 50232
	 * @param shareType	String	分享平台（数据字典）	Y
	 * @param flag	String	分享状态（0：失败，1：成功)	Y
	 * @param info	String	备注信息	N
	 */
	oMyMsgFunction.function50232 = function(paramMap) 
	{
		if(paramMap)
		{
			layerUtils.iAlert("通知H5分享后的状态50232" + JSON.stringify(paramMap));
		}
	}
	
	/**
	 * 公用		
	 * 验证手势密码中忘记密码，修改账号回调H5
	 * @param funcNo 50262
	 * @param type	String	类型(0：忘记密码，1：修改账号）	N
	 */
	oMyMsgFunction.function50262 = function(paramMap) 
	{
		if(paramMap)
		{
			layerUtils.iAlert("验证手势密码中忘记密码，修改账号回调H550262" + JSON.stringify(paramMap));
		}
	}

	/**
	 * 公用		
	 * 扫描图片二维码的内容回调给H5页面	
	 * @param funcNo 50272
	 * @param content	String	内容	Y
	 */
	oMyMsgFunction.function50272 = function(paramMap) 
	{
		if(paramMap)
		{
			layerUtils.iAlert("扫描图片二维码的内容回调给H5页面	50272" + JSON.stringify(paramMap));
		}
	}
	
	/**
	 * 原生点击股票买卖
	 * @param paramMap json格式参数
	 */
	 oMyMsgFunction.function60252 = function(param) {
		try{
			var loginType = param.loginType;
			if(loginType == "1"){
				appUtils.pageInit("account/login","credit/order/mainOrder",{"topage":"credit/order/mainOrder"});
			}else{
				appUtils.pageInit("account/login","stock/stockBuy",{"topage":"stock/stockBuy"});
			}
		}catch(e){
			console.log("原生跳转H5传入数据解析JSON出错"+e.message);
	    }
	}
	
	/**
	 * 原生点击股票买卖
	 * @param paramMap json格式参数
	 */
	 oMyMsgFunction.function60250 = function(param) {
		try{
			var type = param.type;//买卖类型
			var code = param.code;//股票代码
			var market = param.market;//市场
			var param = {"stockCode":code};
			appUtils.setSStorageInfo("_loginInPageParam",JSON.stringify(param));
			if(type=="buy"){
				appUtils.setSStorageInfo("_loginInPageCode","stock/stockBuy");
				appUtils.pageInit(null,"stock/stockBuy",{"stockCode":code});
			}else if(type=="sell"){
				appUtils.setSStorageInfo("_loginInPageCode","stock/stockSell");
				appUtils.pageInit(null,"stock/stockSell",{"stockCode":code});
			}else if(type=="creditBuy"){
				appUtils.setSStorageInfo("_loginInPageCode","credit/order/financingToBuy");
				var credit_userInfo = appUtils.getSStorageInfo("credit_userInfo");
				if(credit_userInfo){
					appUtils.pageInit(null,"credit/order/financingToBuy",{"stockCode":code});
				}else{
					appUtils.pageInit(null,"account/login",{"topage":"credit/order/financingToBuy"});
				}
				
			}else if(type=="creditSell"){
				appUtils.setSStorageInfo("_loginInPageCode","credit/order/financingToSell");
				var credit_userInfo = appUtils.getSStorageInfo("credit_userInfo");
				if(credit_userInfo){
					appUtils.pageInit(null,"credit/order/financingToSell",{"stockCode":code});
				}else{
					appUtils.pageInit(null,"account/login",{"topage":"credit/order/financingToSell"});
				}
			}
		}catch(e){
			console.log("H5获取股票买卖传入数据解析JSON出错"+e.message);
	    }
	}
	
	
	    /**
	    *  统一登录转发跳转页面
	    */
	     oMyMsgFunction.function50113 = function(param)
	     {
	           var toPage = param ? param["toPage"]:null;
	            if(toPage && toPage.length>0&&toPage!="default"){
	        	   var curPageCode = appUtils.getSStorageInfo("_curPageCode"); 
	        	   if(curPageCode){
	                   var pageId = curPageCode.split("/").join("_");
	                   $("#"+pageId).hide(); 
	        	   }
	               if(gconfig.platform == "1"){
	            	 toPage = toPage.substring(0,toPage.length-5);
	                 appUtils.pageInit("",toPage,param);
	               }else if(gconfig.platform == "2"){
	              	 appUtils.pageInit("",toPage,param);
	               }
	           }else{
	        	   appUtils.pageInit("","home/newsHome",{});
	           }
	     }
     
      /**
      *  光大原生首页点击图标跳转页面
      */
       oMyMsgFunction.function50114 = function(param)
       {
    	   try{
	   		    // /mall/index.html#!/account/riskAssessment.html?prePage=fz_marketCon 原生回调格式
	   		    // mall/itemsFinanInfo.html  mall/itemsFinanInfo.html?prePage=fz_marketCon
	   		    //var toPage = "/mall/index.html#!/account/riskAssessment.html?prePage=fz_marketCon";
	   		    //var toPage = "mall/itemsFinanInfo.html?prePage=fz_marketCon";
	   		    //var toPage = "/mall/index.html#!/account/riskAssessment.html";
	   		    //var toPage = "mall/itemsFinanInfo.html";
	   			var toPage = param ? param["toPage"]:null;
	   			var params = {};
	   			if(toPage && toPage.length>0){
	   				var indexOfWH = toPage.indexOf("?"); 
	   				var indexOfDH = toPage.indexOf("=");
	   				var indexOfGTH = toPage.indexOf("!");
	   				var indexOfAND = toPage.indexOf("&");
	   				if(indexOfWH == -1 && indexOfGTH == -1){
	   					toPage = toPage.substring(0,toPage.length-5);
	   				}else if(indexOfWH == -1 && indexOfGTH != -1){
	   					toPage = toPage.substring(indexOfGTH+2,toPage.length-5);
	   				}else if(indexOfWH != -1 && indexOfGTH != -1){
	   					var flagStr = toPage;
	   					var _value = flagStr.substring(indexOfDH+1,flagStr.length);
	   					var _key = flagStr.substring(indexOfWH+1,indexOfDH);
	   					toPage = toPage.substring(indexOfGTH+2,indexOfWH-5);
	   					params[_key] = _value;
	   				}else if(indexOfWH != -1 && indexOfGTH == -1){
	   					var flagStr = toPage;
	   					var _value = flagStr.substring(indexOfDH+1,flagStr.length);
	   					var _key = flagStr.substring(indexOfWH+1,indexOfDH);
	   					toPage = toPage.substring(0,indexOfWH-5);
	   					params[_key] = _value;
	   				}
	   				console.log(JSON.stringify(params));
	   				appUtils.pageInit("",toPage,params);
	   			}
    		}catch(e){
    			console.log("原生跳转H5传入数据解析JSON出错"+e.message);
    	    }
       } 
     
     /**
      *  系统退出
      */
     oMyMsgFunction.function60403 = function(param)
     {
         appUtils.clearSStorage("_isLogin");
         appUtils.clearSStorage(gconfig.projName + "_login_token");
         require.async("common",function(module){
              module.clearSessionUserInfo();
         });
         //调用退出登录接口，请求服务器，失效session
         
     }
	module.exports = oMyMsgFunction;
});